function [x,X] = dtcos(N,m,ft)
%function [x,X] = dtcos(N,m,ft)
%
% compute FFT X[k] of x[n] = cos(2pi/N mn), n = 0,1,...,L
% with period L = N/gcd(N,m)
% where N,m may have a common divisor
%
% compute fourier series coefficient, if ft = 1
%
% examples:   dtcos(40,17);   % no aliasing
%             dtcos(40,26);   % aliasing
% G. Doblinger, TU-Wien, 2007

if nargin == 0
   help dtcos
   return
elseif nargin == 1
   m = 1;
   ft = 1;
elseif nargin == 2
   ft = 1;
end

L = N/gcd(N,m);
if L <= 1
   disp(sprintf('period length = %d', L));
   return;
end

BEAMER = 0;                   % if 1, then beamer style is used  
close all;
clear style;
clear labelfont;
if BEAMER == 1
   fpos = [0.1 0.1 0.8 0.8];
   style{1} = 'LineWidth';    % set plot style for presentation with beamer
   style{2} = 2;
   style{3} = 'MarkerSize';
   style{4} = 6;
   labelfont{1} = 'FontSize';
   labelfont{2} = 16;
   set(0,'DefaultAxesfontname','-*-verdana-medium-r-*-*-*-*-*-*-*-*-*-*');
   set(0,'DefaultAxesfontsize',10);
else
   fpos = [0.2 0.4 0.6 0.55];
   style{1} = 'LineWidth';
   style{2} = 1;
   style{3} = 'MarkerSize';
   style{4} = 4;
   labelfont{1} = 'FontSize';
   labelfont{2} = 12;
   set(0,'DefaultAxesfontname','verdana');
   set(0,'DefaultAxesfontsize',10);
end
figure('numbertitle','off','name','periodic signals',...
       'Units','normal','Position',fpos);

n = [0:N];
theta0 = 2*pi*m/N;
x = cos(theta0*n);
M = 20;                           % use interpolation by factor M
na = [0:M*N];
xi = cos(theta0/M*na);            % interpolated signal
if theta0 > pi
   xa = cos((2*pi-theta0)/M*na);  % alialsing component
end
if ft == 1
   subplot(3,1,1),
else
   subplot(2,1,1),
end
stem(n,x,style{:});
dn = max(5,round(L/10));
set(gca,'XTick',n(1:dn:end));
xlabel('n'); ylabel('x[n]');
title(sprintf('x[n] = cos(2*pi*m/N n), period = N/gcd(N,m) = %d, gcd(N,m) = %d, (N = %d, m = %d)',...
   L,gcd(N,m),N,m));
t = linspace(0,1,M*N+1);
if ft == 1
   subplot(3,1,2),
else
   subplot(2,1,2),
end
if theta0 <= pi
   plot(t,xi,t(1:M:end),x,'ro',style{:});
   title('samples x[n] of analog cosine x(t) = cos \omega_0 t',labelfont{:});
else
   plot(t,xi,t,xa,'m',t(1:M:end),x,'ro',style{:});
   title('samples x[n] of analog cosine x(t) = cos \omega_0 t, and aliasing component',labelfont{:});
end   
xlabel('t'); ylabel('x(t)');
if ft == 1
   X = fft(x,N);
   Xmag = [X X(1)];
   subplot(3,1,3), stem(n,Xmag,style{:});
   set(gca,'XTick',n(1:dn:end));
   xlabel('k'); ylabel('|X[k]|');
   title('DFT magnitude of x[n]');
end



