% example of project implementation using object oriented programming
% features of MATLAB
% to be used in course 389001 Signal Processing with MATLAB
%
% ecg processing experiment
%
% purpose: initialize parameters and set up class object, perform
%          operations on class object
% requires class definition script ecg_dsp.m
%
% Note: if ecg_dsp.m is changed, then load_ecg_params must be called
%       again to activate changes in the object structure
%
% G.Doblinger, TU-Wien, 10-2009

clear;           % all previous class objects must be removed
load bo55n.mat   % load ecg measurement (normal ecg data)
x = bo55n;       % sampled ecg signal
x = x-mean(x);   % remove mean

fc_lp = 30;      % low pass cutoff frequency in Hz
fc_hp = 2;       % high pass cutoff frequency in Hz (use this with bo55n)
Nfir = 150;      % FIR filter length

% create ecg object

e = ecg_dsp(x,fc_lp,fc_hp,Nfir,'ecg signal processing');

%%

% plot processed signal which is computed automatically

plot(e);

%%

% plot spectral magnitude of original signal

fftplot(e);

%%

% show heart beat rate

e.heart_beat;    % when calling this dependent variable the variable is
                 % automatically computed and displayed

%%

% change input signal and hp cutoff frequency, and repeat

load br109a.mat  % load ecg measurement (anormal)
x = br109a;      % sampled ecg signal
x = x-mean(x);   % remove mean

e.x_ecg = x;
e.fc_hp = 8;     % high pass cutoff frequency in Hz (use this with br109a) 

plot(e);
e.heart_beat;

%%

fftplot(e);




