% define simple signal class of vector data
%
% G.Doblinger, TU-Wien, 10-2009

classdef sig
   properties
      x           % signal data (must be a vector)
      Fs          % sampling frequency in Hz
      name        % signal name
   end
   methods
      function ob = sig(x1,Fs,name)
         % signal class constructor
         % must be called before any use of signal class
         
         ob.x = x1;
         ob.Fs = Fs;
         ob.name = name;
      end
      function sum = plus(s1,s2)
         % overload + operator for adding signal class objects
         
         if s1.Fs ~= s2.Fs
            error('signals must have same sampling rate');
         elseif (min(size(s1.x)) || min(size(s2.x))) ~= 1
            error('signal must be vectors');
         end
         Fs_sum = s1.Fs;
         name_sum = 'sum of signals';
         N1 = length(s1.x);
         N2 = length(s2.x);
         Nsum = max(N1,N2);
         if N1 < Nsum
            fprintf(1,'zeropadding %s\n',s1.name);
            y = [s1.x(:) ;zeros(Nsum-N1,1)] + s2.x(:);
         elseif N2 < Nsum
            fprintf(1,'zeropadding %s\n',s2.name);
            y = [s2.x(:) ;zeros(Nsum-N2,1)] + s1.x(:);
         else
            y = s1.x(:) + s2.x(:);
         end
         if size(s1.x,1) == 1
            y = y.';
         end
         sum = sig(y,Fs_sum,name_sum);  % create function return object
      end
      function plot(s)
         % time domain plot used with signal class
         
         t = (0:length(s.x)-1)/s.Fs;
         close all;
         pos = [0.01 0.4 0.5 0.5];
         figure('numbertitle','off','name',s.name,'Units',...
            'normal','Position',pos);
         plot(t,s.x), grid on;
         xlabel('sec.'), ylabel('amplitude');
         title(s.name);
      end
      function fftplot(s,Nfft)
         % plot spectrum magnitude of signal
         % Nfft = optional FFT length
         
         if nargin == 1
            Nfft = length(s.x);
         end
         X = fft(s.x,Nfft);
         Nfh = Nfft/2+1;
         f = linspace(0,s.Fs/2,Nfh);
         N = length(s.x);
         t = 1/s.Fs*(0:N-1);
         close all;
         pos = [0.01 0.4 0.5 0.5];
         figure('numbertitle','off','name',s.name,'Units',...
            'normal','Position',pos);
         subplot(2,1,1), plot(t,s.x), grid on;
         xlabel('sec.'), ylabel('amplitude');
         subplot(2,1,2), plot(f,abs(X(1:Nfh))), grid on;
         xlabel('Hz'), ylabel('spectral magnitude');
         title(sprintf('FFT length = %d',Nfft));
      end
   end
end
         
