function D = ThresCoef(D,keepapp,SorH,threshold)
%function D = ThresCoef(D,keepapp,SorH,threshold)
%
% apply threshold to wavelet packet coefficients
%
% keepapp   if 1, then approximation (low pass) coefficients are not thresholded
% SorH      's', for soft thresholding
%           'h', for hard thresholding
% threshold threshold value

% G. Doblinger, TU-Wien, 9.12.97

[tn,an] = TermNodes(D);    % get terminal nodes and approximation node

if keepapp
   tn = setdiff(tn,an);    % modify only terminal nodes not contained in an
end

switch lower(SorH)
   case 's'
      for n = 1:length(tn)
         k = D.start(tn(n)):D.stop(tn(n));
         dco = abs(D.coef(k))-threshold;
         dco = 0.5*(dco+abs(dco));
         D.coef(k) = sign(D.coef(k)).*dco;
      end
   case 'h'
      for n = 1:length(tn)
         k = D.start(tn(n)):D.stop(tn(n));
         D.coef(k) = D.coef(k).*(abs(D.coef(k))>threshold);
      end
   otherwise
      error('no such threshold type');
end
