function x = WavePackRec(D,LoF_R,HiF_R)
%function x = WavePackRec(D,LoF_R,HiF_R)
%
% reconstruction for wavelet packet tree
%
% D            structure of node data
%              D.coef     node coefficients concatenated to row vector
%              D.start    start index of coeff. for each node
%              D.stop     stop index of coeff. for each node
%              D.root     index of root node for each node (top node = index 0)
%              D.entr     entropy for each node (node is omitted, if its entr. = NaN)
%              D.engy     energy for each node
% LoF_R,HiF_R  reconstruction filter coefficient vectors (must have same length)
% x            output signal vector

% G. Doblinger, TU-Wien, 9.12.97

Nnodes = length(D.entr);                  % number of nodes in the tree

for n = Nnodes:-2:4
   if ~isnan(D.entr(n))                   % modify root node coefficients
      y = ConvInt(D.coef(D.start(n-1):D.stop(n-1)),LoF_R) + ...
          ConvInt(D.coef(D.start(n):D.stop(n)),HiF_R);
      n_root = D.start(D.root(n)):D.stop(D.root(n));
      D.coef(n_root) = y(1:length(n_root));

      % just for MATLAB adjust signal lengths

%      if length(n_root) == length(x_lo)
%         D.coef(n_root) = x_lo+x_hi;
%      if length(n_root) > length(x_lo)
%         D.coef(n_root) = [x_lo+x_hi 0];
%      else
%         x_lo = x_lo+x_hi;
%         D.coef(n_root) = x_lo(1:length(n_root));
%      end
   end
end

% compute output signal (coeff. of topmost node)

x = ConvInt(D.coef(D.start(2):D.stop(2)),HiF_R) + ...
    ConvInt(D.coef(D.start(1):D.stop(1)),LoF_R);
