function y = ConvInt(x,h)
%function y = ConvInt(x,h)
%
% interpolation by 2 and convolution y = x * h
% (version to start with even index, i.e. x(0))
% y(m-1) = sum_(n=max(1,ceil((m-Lh)/2)))^min(Lx,floor((m-1)/2)) h(m-2n) x(n)
%        m = 3 ... 2Lx+Lh
% y(m) = 0, for m = 0,1
% with x given for indices 1 ... Lx
% y is stored in row vector of length 2Lx-Lh+2
% NOTE: y is left shifted by Lh-1 (to compensate for delay), thus length(y) = 2Lx-Lh+2

% G. Doblinger, TU-Wien, 7.12.97

Lh = length(h);
Lx = length(x);
Ly = 2*Lx+Lh;

% for DSP implementation

%y = zeros(1,2*Lx-Lh+2);
%l = 1;
%for m = Lh+1:2*Lx+2
%   for n = ceil((m-Lh)/2):floor((m-1)/2)
%      y(l) = y(l) + h(m-2*n)*x(n);
%   end
%   l = l + 1;
%end

% for MATLAB

y = zeros(1,Ly);
y(1:2:2*Lx) = x(:).';   % NOTE: start with y(1) (needed with start of y(2) in ConvDeci)
y = conv(y,h);          % fast convolution
y = y(Lh-1:Ly-Lh);      % compensate delay

