% denoising using functions of MATLAB wavelet toolbox
%
% G. Doblinger, TU-Wien, 11-2009

SNR = 10;      % SNR in dB of noisy signal

% select type of test signal

sigtype = 'blocks';
%sigtype = 'bumps';      
%sigtype = 'doppler'; 

Nx = 2000;
xc = signals(sigtype,Nx);

% add white Gaussian noise

gain = 10^(-SNR/20);
w = randn(Nx,1);
x = xc + gain/std(w)*w;

% denoise using different threshold rules supported by function wden()

Nlevels = 4;    % number of wavlet tree levels

%th_rule = 'heursure';
%th_rule = 'rigrsure';
th_rule = 'sqtwolog';
%th_rule = 'minimaxi';

hardsoft = 's';
%hardsoft = 'h';

xd = wden(x,th_rule,hardsoft,'one',Nlevels,'sym8');

% show all signals

close all
upperright = [0.55,0.3,0.44,0.65];
figure('name','Denoising with wavelets','Units','normal','Position',upperright);

ymax = max([abs(xc) ; abs(x)]);
subplot(3,1,1), plot(xc), grid on;
axis([0 Nx-1 -ymax ymax]);
xlabel('n'), ylabel('x_c[n]')
title(sprintf('clean signal = %s',sigtype')); 
subplot(3,1,2), plot(x), grid on;
axis([0 Nx-1 -ymax ymax]); 
xlabel('n'), ylabel('x_n[n]')
title(sprintf('noisy signal, SNR = %3.2f dB', SNR)) 
subplot(3,1,3), plot(xd), grid on;
axis([0 Nx-1 -ymax ymax]); 
xlabel('n'), ylabel('x_d[n]')
title(sprintf('denoised signal, threshold rule = %s', th_rule)); 

%%
%
% repeat with functions written by myself 
% (MATLAB wavelet toolbox is not required)

% design wavelet low pass and high pass filters
% (do be used instead of wavelet functions)

h = qmf_2(50,0.65,0.1);

%%
%
% denoise using global threshold algorithm, and wavelet packet function

alg = 'w';    % use wavelets
%alg = 'b';    % use best basis wavelet packets
%alg = 'f';    % use full binary tree
hardsoft = 's';
%hardsoft = 'h';

wpdn_fir(xc,Nx,0,0,SNR,Nlevels,h,alg,hardsoft);

%%
%
% show wavelet spectrum

D = wpspec(xc,Nlevels,h,alg);
