% wavelet spectrum of various signals
%
% G. Doblinger, TU-Wien, 11-2009

% select and show wavelet filters

%wltype = 'db8';
%wltype = 'db45';
%wltype = 'sym8';
%wltype = 'sym12';
wltype = 'coif4';
%wltype = 'dmey';

[h_lp,h_hp] = wfilters(wltype);   % requires MATLAB wavelet toolbox
Nh = length(h_lp);
n = 0:Nh-1;
Fs = 16000;

close all;
figure('name','time domain','Units','normal',...
   'Position',[0.5,0.5,0.49,0.45]);

subplot(2,1,1), stem(n,h_lp);
xlabel('n'), ylabel('h_{lp}[n]');
title(sprintf('wavelet = %s',wltype));
subplot(2,1,2), stem(n,h_hp,'r');
xlabel('n'), ylabel('h_{hp}[n]');
figure('name','frequency domain','Units','normal',...
   'Position',[0.005,0.5,0.49,0.45]);
Nfft = 16*Nh;
Nfh = Nfft/2+1;
H_lp = fft(h_lp,Nfft);
H_hp = fft(h_hp,Nfft);
f = linspace(0,Fs/2,Nfh);
plot(f,20*log10(abs(H_lp(1:Nfh))),'b',f,20*log10(abs(H_hp(1:Nfh))),'r');
grid on, xlabel('f in Hz'), ylabel('magnitude in dB');

%%
%
% select type of test signal

sigtype = 'blocks';
%sigtype = 'bumps';      
%sigtype = 'doppler';   

Nx = 2000;
x = signals(sigtype,Nx);

Nlevels = 3;   % levels of wavelet tree
alg = 'w';    % use wavelets
%alg = 'b';    % use best basis wavelet packets
%alg = 'f';    % use full binary tree

wpspec(x,Nlevels,wltype,alg);

%%
%
% repeat with functions written by myself 
% (MATLAB wavelet toolbox is not required)

% design wavelet low pass and high pass filters
% (do be used istead of wavelet functions)

h = qmf_2(50,0.65,0.1);

%%

wpspec(x,Nlevels,h,alg);

