function cycl_method_test(T)
% cycl_method_test(T)....
% Dieses Funktion dient zum Testen der Laufzeit einiger Algorithmen zur
% Berechnung zyklischer Matrizen der Dimension T.
% Dabei wird die Zeit, die zur Berechnung notwendig ist herausgestoppt und geplottet. 
% 
% Beispiel: cycl_method_test(100);
%
% Author: Konrad Schwarzjirg (Teilnehmer 389001 "Signalverarbeitung mit
% MATLAB", 11-2009)

close all;

if nargin == 0
   T = 100;
end
st1 = zeros(1,T-1);
st2 = zeros(1,T-1);
st3 = zeros(1,T-1);
st4 = zeros(1,T-1);
for t=2:T          % es werden alle Matrixdimensionen durchlaufen
   h=rand(t,1)';   % Es wird ein Vektor der Dimension t per random erstellt
                   % Der Vektor h dient als Basis fr die zyklische
                   % Matrix 
   N=length(h);
  
   % Methode1
   % Dabei wird jeder Eintrag der Matrix einzeln berechnet. Jedes Element
   % der Matrix wird ber 2 For-schleifen erreicht und jeweils mit Modulo
   % berechnet
  
   tic     % Start der Stopuhr
   H = zeros(N);
   for i=1:N
      for j=1:N
         H(i,j)=h(mod(i-j,N)+1);
      end
   end
   st1(t)=toc;     % Die Zeit wird gestoppt und der jeweilige Wert wird gespeichert    
    
   % Methode2 Buch Doblinger
   % Die zyklische Matrix wird rein durch geschickte Matrix Manipulation
   % aufgebaut. 
   
   tic
   h=h(:);
   h1=[h(2:N);h];
   ic=(0:N-1)';
   ir=N:-1:1;
   Hc=ic(:,ones(N,1)) + ir(ones(N,1),:);
   Hc(:)=h1(Hc);

   st2(t)=toc;

   % Methode3
   % Bei dieser Methode wird der Vektor h an sich hinten angehngt. Dann wird
   % mittels der im Buch vorgestellten Methode zur Berechnung der Matrix fr
   % die lineare Konvolution die zyklische Matrix berechnet.
   % Vorteil : nur eine For Schleife
   % Nachteil: doppelt so groe Matrix mu im Speicher angelegt werden

   tic
   k=[h h];
   k=k(:);
   I=zeros(2*N,N);
   for i=1:N
      I(i:i+2*N-1,i)=k;
   end

   I=I(N+1:2*N,:);
   st3(t)=toc;

   % Methode4
   % Bei dieser Methode wird die Matrix aus dem Vektor h aufgebaut der pro
   % Spalte um einen Index weiter verschoben wird und zur Matrix
   % hinzugefgt wird
   
   tic
   r=h(:);
   L = [r zeros(N,N-1)];
   for i=1:N-1
      L(:,i+1) = circshift(r,i);
   end
   st4(t)=toc;

end

scrsz = get(0,'ScreenSize');   % Einlesen der Screenparameter um das Fenster anzupassen
figure('Position',[scrsz(3)/4, scrsz(4)/8, scrsz(3)/2,scrsz(4)*3/4 ])

% Ausgabe der Zeit in sec
t = 1:T;
plot(t,st1,'b', t, st2,'g', t, st3,'r', t, st4,'k');

legend('Methode1','Methode2 Buch Doblinger','Methode3',...
   'Methode4 (circshift)','Location','Northwest');
title('Vergleich einiger Methoden zur Erstellung zyklischer Matrizen');
xlabel('Dimension der Matrix'); ylabel('Rechenzeit in sec.'); grid on;


% berprfung der vier Matrizen auf Gleichheit 

if (H-Hc)>0 
    disp('die Methoden erzeugen unterschiedliche Matrizen');
end
if (H-I)>0 
    disp('die Methoden erzeugen unterschiedliche Matrizen');
end
if abs((H-L))>0 
    disp('die Methoden erzeugen unterschiedliche Matrizen');
end

    
